##  Fact Sheet Structure
The fact sheet body's structure is determined by the order of elements on the Fields tab of the fact sheet configuration page. Sections serve as larger containers, housing subsections. Subsections store fact sheet fields. To learn how fact sheets appear in the inventory, see [Fact Sheet Layout](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a1d567a441014ad58f796eb29a24d__fact_sheet_layout).
In the following image, Information is a section, Name & Description is a subsection, and Name and Alias are fields.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274867007a4410148e8c9b4dc59d197c_LowRes.png)
Section, Subsection, and Fields on a Fact Sheet
You can reorder, add, and modify sections and subsections to adjust the fact sheet structure to your needs. Additionally, you can change the order of fields within subsections.
You can only delete empty sections and subsections. When deleting non-empty elements, they’re moved to the Unused Fields and Relations section, becoming hidden for users. For additional information, see [Unused Fields and Relations](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275955467a441014a5dce078bf2e383c__unused_fields_and_relations).
